@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import contextlib
 import os
+import shutil
 import sys
 
 from pathlib import Path
@@ -86,6 +87,14 @@ def wd(tmp_path: Path) -> WorkDir:
     return WorkDir(target_wd)
 
 
+@pytest.fixture(scope="session")
+def hg_exe() -> str:
+    hg = shutil.which("hg")
+    if hg is None:
+        pytest.skip("hg executable not found")
+    return hg
+
+
 @pytest.fixture
 def repositories_hg_git(tmp_path: Path) -> tuple[WorkDir, WorkDir]:
     tmp_path = tmp_path.resolve()
